/******************************************************************/
/* ACM ICPC 2012-2013                                             */
/* Northeastern European Regional Contest                         */
/* St Petersburg - Barnaul - Tashkent - Tbilisi, December 2, 2012 */
/******************************************************************/
/* Problem D. Disjoint Regular Expressions                        */
/*                                                                */
/* Original idea         Roman Elizarov                           */
/* Problem statement     Andrey Stankevich                        */
/* Test set              Andrey Stankevich                        */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Roman Elizarov                           */
/******************************************************************/

import java.io.*;
import java.util.*;

/**
 * Solution for NEERC'2012 Problem D: Disjoint Regular Expressions
 * This solution checks correctness of the input.
 *
 * @author Roman Elizarov
 */
public class disjoint_re {

    private static final char EPS_CHAR = '~';
    private static final boolean DEBUG = false;

    public static void main(String[] args) throws Exception {
        new disjoint_re().go();
    }

    void go() throws Exception {
        read();
        solve();
        write();
    }

    Automata p;
    Automata q;

    void read() throws Exception {
        BufferedReader in = new BufferedReader(new FileReader("disjoint.in"));
        p = parse(in.readLine());
        q = parse(in.readLine());
        assert in.readLine() == null : "extra data";
        in.close();
    }

    private Automata parse(String s) {
        assert s.length() >= 1 && s.length() <= 100 : "length";
        assert !s.contains("" + EPS_CHAR);
        Parser parser = new Parser(s);
        Automata a = parser.parseExpr();
        assert parser.pos == s.length() : "parsed fully";
        if (DEBUG)
            a.dump();
        return a;
    }

    Set<Pair> inq = new HashSet<>();
    List<Pair> queue = new ArrayList<>();
    int head;
    Pair found;

    void solve() {
        Pair start = new Pair(p.start(), q.start());
        queue.add(start);
        inq.add(start);
        while (head < queue.size()) {
            Pair cur = queue.get(head++);
            if (cur != start && cur.p.epsReach().contains(p.finish()) && cur.q.epsReach().contains(q.finish())) {
                found = cur;
                return;
            }
            Set<Transition> pt = cur.p.nonEpsTransitions();
            Set<Transition> qt = cur.q.nonEpsTransitions();
            for (Transition u : pt) {
                for (Transition v : qt) {
                    char c = u.c;
                    if (c != v.c)
                        continue;
                    Pair next = new Pair(u.state, v.state);
                    if (!inq.add(next))
                        continue;
                    next.c = c;
                    next.prev = cur;
                    queue.add(next);
                }
            }
        }
    }

    void write() throws Exception {
        PrintWriter out = new PrintWriter("disjoint.out");
        if (found == null)
            out.println("Correct");
        else {
            out.println("Wrong");
            out.println(answer(found));
        }
        out.close();
    }

    private String answer(Pair found) {
        StringBuilder sb = new StringBuilder();
        while (found.prev != null) {
            sb.append(found.c);
            found = found.prev;
        }
        sb.reverse();
        if (DEBUG)
            System.out.println("--- Answer " + sb);
        return sb.toString();
    }

    static class Parser {
        private final String s;
        int pos;

        public Parser(String s) {
            this.s = s;
        }

        private char cur() {
            return pos < s.length() ? s.charAt(pos) : EPS_CHAR;
        }

        private void next() {
            pos++;
        }

        public Automata parseExpr() {
            Automata a = parseConcat();
            while (cur() == '|') {
                next();
                Automata b = parseConcat();
                a.alter(b);
            }
            return a;
        }

        private Automata parseConcat() {
            Automata a = parseKleeneStar();
            while (true) {
                char c = cur();
                if (c == '(' || c >= 'a' && c <= 'z') {
                    Automata b = parseKleeneStar();
                    a.concat(b);
                } else
                    return a;
            }
        }

        private Automata parseKleeneStar() {
            Automata a = parseToken();
            while (cur() == '*') {
                next();
                a.kleeneStar();
            }
            return a;
        }

        private Automata parseToken() {
            char c = cur();
            if (c == '(') {
                next();
                Automata a = parseExpr();
                assert cur() == ')';
                next();
                return a;
            }
            if (c >= 'a' && c <= 'z') {
                next();
                return new Automata(c);
            }
            throw new AssertionError("Unexpected char " + c);
        }
    }

    static class Automata {
        final List<State> states = new ArrayList<State>();

        public Automata(char c) {
            State start = new State();
            State finish = new State();
            start.transitions.add(new Transition(c, finish));
            states.add(start);
            states.add(finish);
        }

        public void kleeneStar() {
            State start = new State();
            State finish = new State();
            start.transitions.add(new Transition(EPS_CHAR, finish));
            start.transitions.add(new Transition(EPS_CHAR, start()));
            finish.transitions.add(new Transition(EPS_CHAR, start));
            finish().transitions.add(new Transition(EPS_CHAR, finish));
            states.add(0, start);
            states.add(finish);
        }

        public void concat(Automata b) {
            finish().transitions.add(new Transition(EPS_CHAR, b.start()));
            states.addAll(b.states);
        }

        public void alter(Automata b) {
            State start = new State();
            State finish = new State();
            start.transitions.add(new Transition(EPS_CHAR, start()));
            start.transitions.add(new Transition(EPS_CHAR, b.start()));
            finish().transitions.add(new Transition(EPS_CHAR, finish));
            b.finish().transitions.add(new Transition(EPS_CHAR, finish));
            states.add(0, start);
            states.addAll(b.states);
            states.add(finish);
        }

        public State finish() {
            return states.get(states.size() - 1);
        }

        public State start() {
            return states.get(0);
        }

        public void dump() {
            System.out.println("--- " + states.size() + " states");
            Map<State, Integer> ns = new HashMap<>();
            for (int i = 0; i < states.size(); i++) {
                State state = states.get(i);
                ns.put(state, i);
            }
            for (int i = 0; i < states.size(); i++) {
                State state = states.get(i);
                System.out.print(i + ":");
                for (Transition t : state.transitions) {
                    System.out.print(" " + t.c + "->" + ns.get(t.state));
                }
                System.out.print(" ;;");
                for (Transition t : state.nonEpsTransitions()) {
                    System.out.print(" " + t.c + "->" + ns.get(t.state));
                }
                System.out.println();
            }

        }
    }

    static class State {
        final Set<Transition> transitions = new HashSet<>();
        Set<Transition> nonEpsTransitions;
        Set<State> epsReach;

        public Set<Transition> nonEpsTransitions() {
            if (nonEpsTransitions == null)
                compute();
            return nonEpsTransitions;
        }

        public Set<State> epsReach() {
            if (epsReach == null)
                compute();
            return epsReach;
        }

        private void compute() {
            nonEpsTransitions = new HashSet<>();
            epsReach = new HashSet<>();
            visit(this);
            for (State s : epsReach) {
                for (Transition t : s.transitions) {
                    if (t.c != EPS_CHAR)
                        nonEpsTransitions.add(t);
                }
            }
        }

        private void visit(State state) {
            if (!epsReach.add(state))
                return;
            for (Transition t : state.transitions) {
                if (t.c == EPS_CHAR)
                    visit(t.state);
            }
        }
    }

    static class Transition {
        final char c;
        final State state;

        Transition(char c, State state) {
            this.c = c;
            this.state = state;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (!(o instanceof Transition)) return false;
            Transition that = (Transition) o;
            return c == that.c && state.equals(that.state);
        }

        @Override
        public int hashCode() {
            return 31 * (int) c + state.hashCode();
        }
    }

    static class Pair {
        final State p;
        final State q;
        Pair prev;
        char c;

        Pair(State p, State q) {
            this.p = p;
            this.q = q;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (!(o instanceof Pair)) return false;
            Pair pair = (Pair) o;
            return p.equals(pair.p) && q.equals(pair.q);
        }

        @Override
        public int hashCode() {
            return 31 * p.hashCode() + q.hashCode();
        }
    }
}



